<?php

namespace Drupal\commerce_payment_mkb\PluginForm\OffsiteRedirect;

use Drupal\commerce_order\Entity\OrderItemInterface;
use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm as BasePaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Mkb\Sdk\Signature;
use Mkb\Sdk\Helper;

class PaymentOffsiteForm extends BasePaymentOffsiteForm
{

	/**
	 * {@inheritdoc}
	 */
	public function buildConfigurationForm(array $form, FormStateInterface $form_state)
	{
		$form = parent::buildConfigurationForm($form, $form_state);

		/** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
		$payment = $this->entity;
		/** @var \Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayInterface $payment_gateway_plugin */
		$payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();

		$configuration = $payment_gateway_plugin->getConfiguration();

		$amount = $payment->getAmount()->getNumber() * 100;
		$amount = sprintf('%012d', $amount);

		$transaction_id = $payment->getOrderId();
		$order = $payment->getOrder();

		$data = [
			'mid'           => $configuration['mid'],
			'aid'           => 443222,
			'amount'        => $amount,
			'oid'           => $transaction_id,
			'redirect_url'  => $form['#return_url'],
			'cancel_link'   => $form['#cancel_url'],
			'directposturl' => $payment_gateway_plugin->getNotifyUrl()->toString(),
			'client_mail'   => $order->getCustomer()->getEmail(),
		];

		if ($configuration['merchant_mail']) {
			$data['merchant_mail'] = $configuration['merchant_mail'];
		}

		$data['signature'] = Signature::calcPaymentFormSign($data, $configuration['secret']);
		$redirect_url = Helper::getMpiUrl($configuration['mode'] === 'test');

		$form = $this->buildRedirectForm($form, $form_state, $redirect_url, $data, 'post');
		return $form;
	}
}
